# PyRP
A Ranked Pairs Python Module

This module will eventually contain implementations of all popular ranked choice voting methods in a single lightweight python package. At present, only Ranked Pairs has been implemented.
